//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using MindFusion.Scheduling;
using MindFusion.Scheduling.WinForms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.DataBinding
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			_appPath = System.IO.Path.GetDirectoryName(Application.ExecutablePath);

			_lbInfo.DocumentText = Properties.Resources.Info;
			_lbInfo.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(OnDocumentCompleted);
		}

		private void OnDocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
		{
			if (_lbInfo.Document != null)
			{
				_lbInfo.Document.Click += Document_Click;
				_lbInfo.Document.Body.Style = "font-family: Verdana, Arial, Helvetica, sans-serif; " +
					"font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default;";
			}
		}

		/// <summary>
		/// Handles the Web browser document's Click event.
		/// </summary>
		private void Document_Click(object sender, HtmlElementEventArgs e)
		{
			e.ReturnValue = true;

			HtmlElement pointed = _lbInfo.Document.GetElementFromPoint(e.ClientMousePosition);
			if (pointed == null)
				return;

			if (pointed.TagName.ToLower() == "a")
			{
				string href = pointed.GetAttribute("href").ToLower();
				if (href.StartsWith("help:"))
				{
					string topic = href.Substring(5);
					string helpFile = ResolveHelpPath(_appPath);

					if (System.IO.File.Exists(helpFile))
					{
						Help.ShowHelp(this, helpFile, HelpNavigator.Topic, topic);

						// Prevent link follow
						e.ReturnValue = false;
					}
				}
			}
		}

		private static string ResolveHelpPath(string baseDir)
		{
			string[] helpFiles = new string[]
			{
				"MindFusion.Scheduling.chm",
				"MindFusion WinForms.chm"
			};

			System.IO.DirectoryInfo dirInfo = new System.IO.DirectoryInfo(baseDir);
			int i = 0;
			while (dirInfo != null)
			{
				string helpFile = System.IO.Path.Combine(dirInfo.FullName, helpFiles[i]);
				if (System.IO.File.Exists(helpFile))
					return helpFile;

				i++;
				if (i == helpFiles.Length)
				{
					i = 0;
					dirInfo = dirInfo.Parent;
				}
			}

			return string.Empty;
		}

		private void OnAbout(object sender, System.EventArgs e)
		{
			System.Reflection.Assembly assembly = System.Reflection.Assembly.GetAssembly(
				typeof(MindFusion.Scheduling.WinForms.Calendar));

			if (assembly == null)
				return;

			Type aboutFormType = assembly.GetType(
				"MindFusion.Scheduling.WinForms.AboutForm");

			if (aboutFormType == null)
				return;

			((Form)Activator.CreateInstance(aboutFormType)).ShowDialog(this);
		}

		private void OnExit(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void _btnSaveData_Click(object sender, EventArgs e)
		{
			_calendar.SaveToDataSource(
				_reminderAdapter,
				_styleAdapter,
				_customBrushesAdapter,
				_contactAdapter,
				_locationAdapter,
				_resourceAdapter,
				_taskAdapter,
				_itemAdapter,
				_itemContactsAdapter,
				_itemResourcesAdapter,
				_recurrenceAdapter,
				_recurrenceExceptionAdapter,
				_recurrenceExceptionsAdapter
			);
		}

		private void _btnLoadData_Click(object sender, EventArgs e)
		{
			_calendar.Schedule.Clear();
			_plannerSet.Clear();

			_reminderAdapter.Fill(_plannerSet.Reminder);
			_styleAdapter.Fill(_plannerSet.Style);
			_customBrushesAdapter.Fill(_plannerSet.CustomBrushes);
			_contactAdapter.Fill(_plannerSet.Contact);
			_locationAdapter.Fill(_plannerSet.Location);
			_resourceAdapter.Fill(_plannerSet.Resource);
			_taskAdapter.Fill(_plannerSet.Task);
			_itemAdapter.Fill(_plannerSet.Item);
			_itemContactsAdapter.Fill(_plannerSet.ItemContacts);
			_itemResourcesAdapter.Fill(_plannerSet.ItemResources);
			_recurrenceAdapter.Fill(_plannerSet.Recurrence);
			_recurrenceExceptionAdapter.Fill(_plannerSet.RecurrenceException);
			_recurrenceExceptionsAdapter.Fill(_plannerSet.RecurrenceExceptions);

			_calendar.LoadFromDataSource();
		}

		private void _btnClear_Click(object sender, EventArgs e)
		{
			_calendar.Schedule.Clear();
		}

		private void _calendar_ItemCreated(object sender, MindFusion.Scheduling.ItemEventArgs e)
		{
			Contact c = new Contact();
			c.FirstName = "jo";
			_calendar.Schedule.Contacts.Add(c);

			Item i = e.Item;

			Recurrence r = new Recurrence();
			r.Pattern = RecurrencePattern.Daily;
			r.Days = 3;
			r.StartDate = e.Item.StartTime;

			i.Contacts.Add(c);
			i.Recurrence = r;
		}


		private string _appPath;
	}
}